@@ -22,8 +22,8 @@
  * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
  * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
-#ifndef NGTCP2_HTTP_TEST_H
-#define NGTCP2_HTTP_TEST_H
+#ifndef NGHTTP3_HTTP_TEST_H
+#define NGHTTP3_HTTP_TEST_H
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -32,4 +32,4 @@
 void test_nghttp3_http_parse_priority(void);
 void test_nghttp3_check_header_value(void);
 
-#endif /* NGTCP2_CONN_TEST_H */
+#endif /* NGHTTP3_HTTP_TEST_H */
